@@ -1,10 +1,7 @@
 package Crypt::PBKDF2::Hash;
-BEGIN {
-  $Crypt::PBKDF2::Hash::VERSION = '0.112020';
-}
-
 # ABSTRACT: Abstract role for PBKDF2 hashing algorithms.
-
+our $VERSION = '0.121930'; # VERSION
+our $AUTHORITY = 'cpan:ARODLAND'; # AUTHORITY
 use Moose::Role;
 use namespace::autoclean;
 
@@ -28,7 +25,7 @@ Crypt::PBKDF2::Hash - Abstract role for PBKDF2 hashing algorithms.
 
 =head1 VERSION
 
-version 0.112020
+version 0.121930
 
 =head1 METHODS
 
@@ -60,7 +57,7 @@ Andrew Rodland <arodland@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Andrew Rodland.
+This software is copyright (c) 2012 by Andrew Rodland.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
