@@ -1,9 +1,7 @@
 package Crypt::PBKDF2::Hash::HMACSHA1;
-BEGIN {
-  $Crypt::PBKDF2::Hash::HMACSHA1::VERSION = '0.112020';
-}
 # ABSTRACT: HMAC-SHA1 support for Crypt::PBKDF2 using Digest::SHA
-
+our $VERSION = '0.121930'; # VERSION
+our $AUTHORITY = 'cpan:ARODLAND'; # AUTHORITY
 use Moose;
 use namespace::autoclean;
 use Digest::SHA ();
@@ -41,7 +39,7 @@ Crypt::PBKDF2::Hash::HMACSHA1 - HMAC-SHA1 support for Crypt::PBKDF2 using Digest
 
 =head1 VERSION
 
-version 0.112020
+version 0.121930
 
 =head1 DESCRIPTION
 
@@ -54,7 +52,7 @@ Andrew Rodland <arodland@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Andrew Rodland.
+This software is copyright (c) 2012 by Andrew Rodland.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
